@@ -32,16 +32,14 @@
 #'
 #' @examples
 #' library(survival)
-#' library(MASS)
 #'
-#' fit(Surv(time, status != 2) ~ sex + age + year + thickness + ulcer,
-#'     data = Melanoma, model = CoxModel)
+#' fit(Surv(time, status) ~ ., data = veteran, model = CoxModel)
 #'
 CoxModel <- function(ties = c("efron", "breslow", "exact"), ...) {
 
   ties <- match.arg(ties)
 
-  args <- params(environment())
+  args <- params(environment(), ...)
   is_main <- names(args) %in% c("ties", "eps", "iter.max")
   params <- args[is_main]
   params$tol <- args$toler.chol
